@@ -2,7 +2,6 @@ package filter
 
 import (
 	"os"
-	"reflect"
 	"strings"
 	"testing"
 
@@ -71,6 +70,10 @@ func TestDriftIgnore_IsResourceIgnored(t *testing.T) {
 					Type: "type1",
 					Id:   "id1",
 				},
+				&resource2.FakeResource{
+					Type: "wildcard_resource",
+					Id:   "id1/with/slash",
+				},
 				&resource2.FakeResource{
 					Type: "wildcard_resource",
 					Id:   "id1",
@@ -99,6 +102,10 @@ func TestDriftIgnore_IsResourceIgnored(t *testing.T) {
 					Type: "resource_type",
 					Id:   "idwith\\backslashes",
 				},
+				&resource2.FakeResource{
+					Type: "resource_type",
+					Id:   "idwith/slashes",
+				},
 			},
 			want: []bool{
 				false,
@@ -109,6 +116,8 @@ func TestDriftIgnore_IsResourceIgnored(t *testing.T) {
 				true,
 				true,
 				true,
+				true,
+				true,
 			},
 			path: "testdata/drift_ignore_valid/.driftignore",
 		},
@@ -155,6 +164,59 @@ func TestDriftIgnore_IsResourceIgnored(t *testing.T) {
 			},
 			path: "testdata/drift_ignore_wildcard/.driftignore",
 		},
+		{
+			name: "drift_ignore_all_exclude",
+			resources: []resource.Resource{
+				&resource2.FakeResource{
+					Type: "type1",
+					Id:   "id1",
+				},
+				&resource2.FakeResource{
+					Type: "type2",
+					Id:   "id1",
+				},
+				&resource2.FakeResource{
+					Type: "type2",
+					Id:   "id11",
+				},
+				&resource2.FakeResource{
+					Type: "type2",
+					Id:   "id2",
+				},
+				&resource2.FakeResource{
+					Type: "type3",
+					Id:   "id100",
+				},
+				&resource2.FakeResource{
+					Type: "type3",
+					Id:   "id101",
+				},
+				&resource2.FakeResource{
+					Type: "iam_user",
+					Id:   "id\\WithBac*slash***\\*\\",
+				},
+				&resource2.FakeResource{
+					Type: "some_type",
+					Id:   "idwith/slash",
+				},
+				&resource2.FakeResource{
+					Type: "some_type",
+					Id:   "idwith/slash/",
+				},
+			},
+			want: []bool{
+				true,
+				true,
+				true,
+				true,
+				true,
+				true,
+				false,
+				false,
+				true,
+			},
+			path: "testdata/drift_ignore_all_exclude/.driftignore",
+		},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
@@ -288,6 +350,77 @@ func TestDriftIgnore_IsFieldIgnored(t *testing.T) {
 			},
 			path: "testdata/drift_ignore_fields/.driftignore",
 		},
+		{
+			name: "drift_ignore_all_exclude_field",
+			args: []Args{
+				{
+					Res:  &resource2.FakeResource{Type: "res_type", Id: "full_drift_ignored"},
+					Path: []string{"json"},
+					Want: true,
+				},
+				{
+					Res:  &resource2.FakeResource{Type: "res_type", Id: "full_drift_ignored"},
+					Path: []string{"foobar"},
+					Want: true,
+				},
+				{
+					Res:  &resource2.FakeResource{Type: "res_type", Id: "partial_drift_ignored"},
+					Path: []string{"json"},
+					Want: true,
+				},
+				{
+					Res:  &resource2.FakeResource{Type: "res_type", Id: "partial_drift_ignored"},
+					Path: []string{"foobar"},
+					Want: true,
+				},
+				{
+					Res:  &resource2.FakeResource{Type: "resource_type", Id: "id.with.dots"},
+					Path: []string{"json"},
+					Want: true,
+				},
+				{
+					Res:  &resource2.FakeResource{Type: "resource_type", Id: "id.with.dots"},
+					Path: []string{"json"},
+					Want: true,
+				},
+				{
+					Res:  &resource2.FakeResource{Type: "resource_type", Id: "idwith\\"},
+					Path: []string{"json"},
+					Want: true,
+				},
+				{
+					Res:  &resource2.FakeResource{Type: "resource_type", Id: "idwith\\backslashes"},
+					Path: []string{"json"},
+					Want: true,
+				},
+				{
+					Res:  &resource2.FakeResource{Type: "resource_type", Id: "idwith\\backslashes"},
+					Path: []string{"foobar"},
+					Want: true,
+				},
+				{
+					Res:  &resource2.FakeResource{Type: "res_type", Id: "wildcard_drift_ignored"},
+					Path: []string{"struct", "baz"},
+					Want: true,
+				},
+				{
+					Res:  &resource2.FakeResource{Type: "res_type", Id: "wildcard_drift_ignored"},
+					Path: []string{"struct", "bar"},
+					Want: false,
+				},
+				{
+					Res:  &resource2.FakeResource{Type: "res_type", Id: "endofpath_drift_ignored"},
+					Path: []string{"struct", "baz"},
+					Want: true,
+				},
+				{
+					Res:  &resource2.FakeResource{Type: "res_type", Id: "endofpath_drift_ignored"},
+					Path: []string{"struct", "bar"},
+					Want: false,
+				},
+			},
+			path: "testdata/drift_ignore_all_exclude_field/.driftignore",
+		},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
@@ -304,59 +437,3 @@ func TestDriftIgnore_IsFieldIgnored(t *testing.T) {
 		})
 	}
 }
-
-func Test_escapableSplit(t *testing.T) {
-	tests := []struct {
-		name string
-		line string
-		want []string
-	}{
-		{
-			name: "Dot at start",
-			line: ".",
-			want: []string{"."},
-		},
-		{
-			name: "Dot at end",
-			line: "test.toto.",
-			want: []string{"test", "toto"},
-		},
-		{
-			name: "wildcard dot",
-			line: "*.subfoobar",
-			want: []string{"*", "subfoobar"},
-		},
-		{
-			name: "text wildcard dot",
-			line: "res*.subfoobar",
-			want: []string{"res*", "subfoobar"},
-		},
-		{
-			name: "missing text multiple wildcard dot",
-			line: "r*s*.s**ub***ob********a*r",
-			want: []string{"r*s*", "s*ub*ob*a*r"},
-		},
-		{
-			name: "prefix wildcard dot",
-			line: "*res.subfoobar",
-			want: []string{"*res", "subfoobar"},
-		},
-		{
-			name: "suffix multiple wildcard dot",
-			line: "res.subfoobar*****",
-			want: []string{"res", "subfoobar*"},
-		},
-		{
-			name: "dot wildcard",
-			line: "res.*",
-			want: []string{"res", "*"},
-		},
-	}
-	for _, tt := range tests {
-		t.Run(tt.name, func(t *testing.T) {
-			if got := readDriftIgnoreLine(tt.line); !reflect.DeepEqual(got, tt.want) {
-				t.Errorf("EscapableSplit() = %v, want %v", got, tt.want)
-			}
-		})
-	}
-}
