@@ -4,6 +4,7 @@ import (
 	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/sns"
 	"github.com/aws/aws-sdk-go/service/sns/snsiface"
+	"github.com/cloudskiff/driftctl/pkg/remote/cache"
 )
 
 type SNSRepository interface {
@@ -13,15 +14,21 @@ type SNSRepository interface {
 
 type snsRepository struct {
 	client snsiface.SNSAPI
+	cache  cache.Cache
 }
 
-func NewSNSClient(session *session.Session) *snsRepository {
+func NewSNSClient(session *session.Session, c cache.Cache) *snsRepository {
 	return &snsRepository{
 		sns.New(session),
+		c,
 	}
 }
 
 func (r *snsRepository) ListAllTopics() ([]*sns.Topic, error) {
+	if v := r.cache.Get("snsListAllTopics"); v != nil {
+		return v.([]*sns.Topic), nil
+	}
+
 	var topics []*sns.Topic
 	input := &sns.ListTopicsInput{}
 	err := r.client.ListTopicsPages(input, func(res *sns.ListTopicsOutput, lastPage bool) bool {
@@ -31,10 +38,16 @@ func (r *snsRepository) ListAllTopics() ([]*sns.Topic, error) {
 	if err != nil {
 		return nil, err
 	}
+
+	r.cache.Put("snsListAllTopics", topics)
 	return topics, nil
 }
 
 func (r *snsRepository) ListAllSubscriptions() ([]*sns.Subscription, error) {
+	if v := r.cache.Get("snsListAllSubscriptions"); v != nil {
+		return v.([]*sns.Subscription), nil
+	}
+
 	var subscriptions []*sns.Subscription
 	input := &sns.ListSubscriptionsInput{}
 	err := r.client.ListSubscriptionsPages(input, func(res *sns.ListSubscriptionsOutput, lastPage bool) bool {
@@ -44,5 +57,7 @@ func (r *snsRepository) ListAllSubscriptions() ([]*sns.Subscription, error) {
 	if err != nil {
 		return nil, err
 	}
+
+	r.cache.Put("snsListAllSubscriptions", subscriptions)
 	return subscriptions, nil
 }
